@@ -10,6 +10,9 @@ from . import (
     sources
 )
 
+OUTPUT_ARTIFACT_FORMAT = typing.Literal['CODEBUILD_CLONE_REF', 'CODE_ZIP']
+
+
 class PipelineStack(core.Stack):
     pipeline: codepipeline.Pipeline=None
     _pipelines: pipelines.CdkPipeline=None
@@ -39,7 +42,13 @@ class PipelineStack(core.Stack):
             )
         return self._pipelines
 
-    def source(self, action_name: str=None, repository: typing.Union[str, sources.SourceRepositoryAttrs]=None, connections: dict=None) -> aws_codepipeline_actions.Action:
+    def source(
+            self,
+            action_name: str=None,
+            repository: typing.Union[str, sources.SourceRepositoryAttrs]=None,
+            connections: dict=None,
+            output_artifact_format: OUTPUT_ARTIFACT_FORMAT='CODEBUILD_CLONE_REF'
+            ) -> aws_codepipeline_actions.Action:
         """Add an action to watch a git reporitory/branch to the Source stage
 
         Args:
@@ -55,7 +64,7 @@ class PipelineStack(core.Stack):
             self.pipeline.connections = connections
         if 'Source' not in self.stages:
             self.stages['Source'] = self.pipeline.add_stage(stage_name='Source')
-        action = self.pipeline.source(action_name=action_name, repository=repository)
+        action = self.pipeline.source(action_name=action_name, repository=repository, output_artifact_format=output_artifact_format)
         self.stages['Source'].add_action(action=action)
         return action
 
